@@ -27,20 +27,20 @@ extern "C" {
 */
 #define MagickPackageName "ImageMagick"
 #define MagickCopyright  "(C) 1999 ImageMagick Studio LLC"
-#define MagickLibVersion  0x69C
-#define MagickLibVersionText  "6.9.12"
+#define MagickLibVersion  0x69D
+#define MagickLibVersionText  "6.9.13"
 #define MagickLibVersionNumber  7,0,0
-#define MagickLibAddendum  "-96"
+#define MagickLibAddendum  "-16"
 #define MagickLibInterface  7
 #define MagickLibMinInterface  7
-#define MagickPlatform  "x86_64"
-#define MagickppLibVersionText  "6.9.12"
+#define MagickPlatform  "aarch64"
+#define MagickppLibVersionText  "6.9.13"
 #define MagickppLibVersionNumber  9:0:0
-#define MagickppLibAddendum  "-96"
+#define MagickppLibAddendum  "-16"
 #define MagickppLibInterface  9
 #define MagickppLibMinInterface  9
-#define MagickGitRevision  "18004"
-#define MagickReleaseDate  "2023-09-23"
+#define MagickGitRevision  "18467"
+#define MagickReleaseDate  "2024-09-01"
 #define MagickHomeURL  "file:///usr/local/share/doc/ImageMagick/index.html"
 #define MagickAuthoritativeLicense  \
   "https://imagemagick.org/script/license.php"
